From 81b3f95622b1da2433f7d1e992c3ae6ad745e704 Mon Sep 17 00:00:00 2001
From: Ben Ramsey <ramsey@php.net>
Date: Tue, 19 Oct 2021 23:59:11 -0500
Subject: [PATCH] Change UBool to bool for equality operators in ICU >= 70.1

Refer to:
- https://github.com/unicode-org/icu/commit/633438f8da99fee815e2c61626ea779a84567a3d
- https://github.com/unicode-org/icu/commit/f6325d49ba57ec26f320b2865ce09ca47db458d9
---
 ext/intl/breakiterator/codepointiterator_internal.cpp | 4 ++++
 ext/intl/breakiterator/codepointiterator_internal.h   | 4 ++++
 2 files changed, 8 insertions(+)

diff --git ext/intl/breakiterator/codepointiterator_internal.cpp ext/intl/breakiterator/codepointiterator_internal.cpp
index bf44678efc06..143c181590e9 100644
--- ext/intl/breakiterator/codepointiterator_internal.cpp
+++ ext/intl/breakiterator/codepointiterator_internal.cpp
@@ -75,7 +75,11 @@ CodePointBreakIterator::~CodePointBreakIterator()
 	clearCurrentCharIter();
 }
 
+#if U_ICU_VERSION_MAJOR_NUM >= 70
+bool CodePointBreakIterator::operator==(const BreakIterator& that) const
+#else
 UBool CodePointBreakIterator::operator==(const BreakIterator& that) const
+#endif
 {
 	if (typeid(*this) != typeid(that)) {
 		return FALSE;
diff --git ext/intl/breakiterator/codepointiterator_internal.h ext/intl/breakiterator/codepointiterator_internal.h
index 7ecf12deb5ae..0baf607782d0 100644
--- ext/intl/breakiterator/codepointiterator_internal.h
+++ ext/intl/breakiterator/codepointiterator_internal.h
@@ -39,7 +39,11 @@ namespace PHP {
 
 		virtual ~CodePointBreakIterator();
 
+#if U_ICU_VERSION_MAJOR_NUM >= 70
+		virtual bool operator==(const BreakIterator& that) const;
+#else
 		virtual UBool operator==(const BreakIterator& that) const;
+#endif
 
 		virtual CodePointBreakIterator* clone(void) const;
 
